![CI](https://github.com/MizarAI/mizar-labs/workflows/CI/badge.svg?branch=master)
[![codecov](https://codecov.io/gh/MizarAI/mizar-labs/branch/master/graph/badge.svg?token=W6VKLA1OF9)](https://codecov.io/gh/MizarAI/mizar-labs)
[![GitHub](https://img.shields.io/github/license/mizarai/mizar-labs)](https://img.shields.io/github/license/mizarai/mizar-labs)
[![PyPi](https://img.shields.io/pypi/v/mizar-labs)](https://img.shields.io/pypi/v/mizar-labs)

# Welcome to Mizar Labs

Mizar Labs is an open source repository containing state of the art machine learning modules specifically designed for working with financial time series. These modules aim to assist the user with building financial machine learning models by taking into account the caveats that arise when dealing with financial time series. A lot of the concepts are inspired by [Marcos Lopez de Prado](https://www.quantresearch.org/) and his book [Advances in Financial Machine Learning (2018)](https://www.amazon.com/Advances-Financial-Machine-Learning-Marcos/dp/1119482089).

Most of the modules follow the [scikit-learn](https://scikit-learn.org/stable/) API and work with methods like `fit` and `transform`.

Please read the [documentation](https://mizarlabs.readthedocs.io/) for further explanation of the modules.

## Installing

Before installing the package please install [TA-Lib dependencies](https://mrjbq7.github.io/ta-lib/install.html)

Install and update with [pip](https://pip.pypa.io/en/stable/quickstart/):

```bash
$ pip install mizar-labs
```

## Tutorials

In the future this section will have links to Jupyter Notebooks explaining how to use the modules.

## Mizar

Mizar is building a marketplace for algo-traders to deploy and share their trading strategies with investors. Please visit the website [mizar.ai](https://mizar.ai/) to learn more.

## Links

- Documentation: [https://mizarlabs.readthedocs.io/](https://mizarlabs.readthedocs.io)
- Website: [https://mizar.ai/](https://mizar.ai/)
- PyPi Releases: [https://pypi.org/project/mizar-labs/](https://pypi.org/project/mizar-labs/)
- Source Code: [https://github.com/MizarAI/mizar-labs](https://github.com/MizarAI/mizar-labs)
